### Multinomial Logit model estimation

### Create the data array from the existing dataset
Data <- read.csv("C:/Program Files/R/nikou.csv",header=TRUE)
## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(4)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  
  ## Travel time to destination
  d1 <- x[2]
  d2 <- x[3]
  d3 <- x[4]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## 駅の近い	(chikai)
  ## 駅から遠い	(tooi)
 
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
                                       
                    #距離					#勤務先駅近			　　　　　　	#近傍駅サービス水準		#定数項						   
  chikai  <- exp(d1*Data$distance/1000000								+d3*Data$yusouryoku/10		+b1*matrix(1,nrow =hh,ncol=1))
  tooi    <- exp(							+d2*Data$kinmusaki_eki)
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (tooi + chikai)
  
  ## Calculate indiviudal choice probabilities
  Pchikai 	<- 1*(chikai / deno)
  Ptooi     <- 1*(tooi   / deno)

  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまった???合に起こる問題???回避
  Pchikai 	<- (Pchikai!=0)*Pchikai + (Pchikai==0)
  Ptooi   	<- (Ptooi!=0)*Ptooi     + (Ptooi==0)
  
  
  
  ## Choice results
  Cchikai   <- Data$jitaku_eki ==1
  Ctooi     <- Data$jitaku_eki ==0
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Cchikai*log(Pchikai) + Ctooi*log(Ptooi))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)
